Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(81)

Unified Diff: tests/corelib/linked_hash_map_from_iterables_test.dart

Issue 18072004: Add fromIterable(s) constructors in SplayTreeMap and LinkedHashMap. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Removed long line. Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/corelib/linked_hash_map_from_iterables_test.dart
diff --git a/tests/corelib/map_from_iterables_test.dart b/tests/corelib/linked_hash_map_from_iterables_test.dart
similarity index 63%
copy from tests/corelib/map_from_iterables_test.dart
copy to tests/corelib/linked_hash_map_from_iterables_test.dart
index 8c21e9f6b2ced4971c45672988ace394a07aa040..0212dd4b4ef7f7041d5f00a44928eb961472f528 100644
--- a/tests/corelib/map_from_iterables_test.dart
+++ b/tests/corelib/linked_hash_map_from_iterables_test.dart
@@ -15,9 +15,10 @@ main() {
}
void positiveTest() {
- var map = new Map.fromIterables([1, 2, 3], ["one", "two", "three"]);
+ var map = new LinkedHashMap.fromIterables([1, 2, 3], ["one", "two", "three"]);
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is LinkedHashMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
@@ -29,9 +30,10 @@ void positiveTest() {
}
void emptyMapTest() {
- var map = new Map.fromIterables([], []);
+ var map = new LinkedHashMap.fromIterables([], []);
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is LinkedHashMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(0, map.length);
Expect.equals(0, map.keys.length);
@@ -39,17 +41,18 @@ void emptyMapTest() {
}
void fewerValuesIterableTest() {
- Expect.throws(() => new Map.fromIterables([1,2], [0]));
+ Expect.throws(() => new LinkedHashMap.fromIterables([1,2], [0]));
}
void fewerKeysIterableTest() {
- Expect.throws(() => new Map.fromIterables([1], [0,2]));
+ Expect.throws(() => new LinkedHashMap.fromIterables([1], [0,2]));
}
void equalElementsTest() {
- var map = new Map.fromIterables([1, 2, 2], ["one", "two", "three"]);
+ var map = new LinkedHashMap.fromIterables([1, 2, 2], ["one", "two", "three"]);
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is LinkedHashMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(2, map.length);
Expect.equals(2, map.keys.length);
@@ -61,13 +64,14 @@ void equalElementsTest() {
void genericTypeTest() {
- var map = new Map<int, String>.fromIterables(
+ var map = new LinkedHashMap<int, String>.fromIterables(
[1, 2, 3], ["one", "two", "three"]);
Expect.isTrue(map is Map<int, String>);
+ Expect.isTrue(map is LinkedHashMap<int, String>);
- // Make sure it is not just Map<dynamic, dynamic>.
- Expect.isFalse(map is Map<String, dynamic>);
- Expect.isFalse(map is Map<dynamic, int>);
+ // Make sure it is not just LinkedHashMap<dynamic, dynamic>.
+ Expect.isFalse(map is LinkedHashMap<String, dynamic>);
+ Expect.isFalse(map is LinkedHashMap<dynamic, int>);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
« no previous file with comments | « tests/corelib/linked_hash_map_from_iterable_test.dart ('k') | tests/corelib/splay_tree_from_iterable_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698